==> js-concat-7.0.0.tgz: package/lib/index.js <==
var __create = Object.create;
var __defProp = Object.defineProperty;
var __getOwnPropDesc = Object.getOwnPropertyDescriptor;
var __getOwnPropNames = Object.getOwnPropertyNames;
var __getProtoOf = Object.getPrototypeOf;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __export = (target, all) => {
  for (var name in all)
    __defProp(target, name, { get: all[name], enumerable: true });
};
var __copyProps = (to, from, except, desc) => {
  if (from && typeof from === "object" || typeof from === "function") {
    for (let key of __getOwnPropNames(from))
      if (!__hasOwnProp.call(to, key) && key !== except)
        __defProp(to, key, { get: () => from[key], enumerable: !(desc = __getOwnPropDesc(from, key)) || desc.enumerable });
  }
  return to;
};
var __toESM = (mod, isNodeMode, target) => (target = mod != null ? __create(__getProtoOf(mod)) : {}, __copyProps(
  // If the importer is in node compatibility mode or this is not an ESM
  // file that has been converted to a CommonJS file using a Babel-
  // compatible transform (i.e. "__esModule" has not been set), then set
  // "default" to the CommonJS "module.exports" for node compatibility.
  isNodeMode || !mod || !mod.__esModule ? __defProp(target, "default", { value: mod, enumerable: true }) : target,
  mod
));
var __toCommonJS = (mod) => __copyProps(__defProp({}, "__esModule", { value: true }), mod);

// src/index.js
var src_exports = {};
__export(src_exports, {
  default: () => concat
});
module.exports = __toCommonJS(src_exports);
var import_promises2 = require("node:fs/promises");

// src/resolver.js
var import_node_path = __toESM(require("node:path"));
var import_promises = __toESM(require("node:fs/promises"));
var REGX_APPEND = /\/\/(\s+|)@(prepros-|codekit-|)append/;
var REGX_PREPEND = /\/\/(\s+|)@(prepros-|codekit-|)prepend/;
var Resolver = class {
  constructor(options) {
    this.file = options.file;
    this.code = options.code;
    this.parents = options.parents;
    this.baseDir = import_node_path.default.dirname(this.file);
    this.rootDir = options.rootDir || this.baseDir;
  }
  async exists(file) {
    return await import_promises.default.access(file, import_promises.default.constants.F_OK).then(() => true).catch(() => false);
  }
  getMatches(regx) {
    let matches = [];
    for (const [index, code] of this.code.split("\n").entries()) {
      if (regx.test(code)) {
        matches = matches.concat(
          code.replace(regx, "").replace(/;|'|"/gi, "").split(",").filter((match) => !!match).map((match) => match.trim().replace(/^quiet\s+/, "").replace(/\s+quiet$/, "")).map((match) => ({ match: match.trim(), line: index + 1 }))
        );
      }
    }
    return matches;
  }
  async _resolveMatch(match) {
    const name = import_node_path.default.basename(match, ".js");
    const possibleNames = [`${name}.js`, `_${name}.js`];
    for (const name2 of possibleNames) {
      const filePath = import_node_path.default.resolve(this.baseDir, import_node_path.default.dirname(match), name2);
      if (await this.exists(filePath))
        return filePath;
    }
    throw new Error(`Unable to find the included file \`${match}\``);
  }
  // resolve full path/paths of a match
  async resolveMatch({ match, line }) {
    let files = [];
    try {
      files = files.concat(await this._resolveMatch(match));
      files.forEach((file) => {
        if (file === this.file)
          throw new Error(`\`${import_node_path.default.relative(this.rootDir, file)}\` can not be appended/prepended to itself`);
      });
      files.forEach((file) => {
        if (this.parents.includes(file))
          throw new Error(`\`${import_node_path.default.relative(this.rootDir, this.file)}\` can not append/prepend the parent file \`${import_node_path.default.relative(this.rootDir, file)}\``);
      });
    } catch (err) {
      err.line = line;
      err.column = 1;
      err.file = this.file;
      throw err;
    }
    return files;
  }
  async resolve(regx) {
    let result = [];
    const matches = this.getMatches(regx);
    for (const { match, line } of matches) {
      result = result.concat(await this.resolveMatch({ match, line }));
    }
    return result;
  }
  async resolveAll() {
    const [prepends, appends] = await Promise.all(
      [REGX_PREPEND, REGX_APPEND].map((regx) => this.resolve(regx))
    );
    return { prepends, appends };
  }
};

// src/join-sources.js
var import_source_map = require("source-map");
var REGX_APPEND2 = /\/\/(\s+|)@(prepros-|codekit-|)append/;
var REGX_PREPEND2 = /\/\/(\s+|)@(prepros-|codekit-|)prepend/;
var REGX_SOURCEMAP = /\/\/(\s+|)[@#](\s+|)sourceMappingURL=/;
function slash(path2) {
  return path2.replaceAll("\\", "/");
}
async function joinWithoutSourceMap(sources) {
  return sources.map((source) => {
    return source.code.split("\n").filter((line) => !REGX_APPEND2.test(line)).filter((line) => !REGX_PREPEND2.test(line)).filter((line) => !REGX_SOURCEMAP.test(line)).join("\n");
  }).join("\n");
}
async function joinWithSourceMap(sources) {
  const result = new import_source_map.SourceNode();
  for (const source of sources) {
    let inputMap = source.map ? await new import_source_map.SourceMapConsumer(source.map) : null;
    for (const [lineIndex, line] of source.code.split("\n").entries()) {
      if (REGX_APPEND2.test(line))
        continue;
      if (REGX_PREPEND2.test(line))
        continue;
      if (REGX_SOURCEMAP.test(line))
        continue;
      for (const [columnIndex, column] of line.split("").entries()) {
        let position = {
          line: lineIndex + 1,
          column: columnIndex + 1,
          source: slash(source.file)
        };
        if (inputMap) {
          const originalPosition = inputMap.originalPositionFor({ line: position.line, column: position.column });
          if (originalPosition && originalPosition.source) {
            position = { line: originalPosition.line, column: originalPosition.column, source: slash(originalPosition.source) };
          }
        }
        result.add(new import_source_map.SourceNode(position.line, position.column, position.source, column));
      }
      result.add("\n");
    }
    if (inputMap)
      inputMap.destroy();
  }
  return result.toStringWithSourceMap();
}
async function joinSources(sources, { sourceMap }) {
  if (sourceMap)
    return await joinWithSourceMap(sources);
  return { code: await joinWithoutSourceMap(sources), map: null };
}

// src/index.js
async function readCodeMap(file, readMap) {
  const code = await (0, import_promises2.readFile)(file, "utf-8");
  if (!readMap)
    return { code };
  const map = await (0, import_promises2.readFile)(`${file}.map`, "utf-8").catch(() => {
  });
  return { code, map };
}
async function getSources({ file, code, map, readMap, rootDir, parents }) {
  if (!file)
    throw new Error("`file` is required");
  if (typeof code !== "string")
    throw new Error("`code` must be a string");
  if (!parents)
    parents = [];
  let sources = [];
  const children = await new Resolver({ file, code, rootDir, parents }).resolveAll();
  const childOptions = { readMap, rootDir, parents: parents.concat(file) };
  for (const prepend of children.prepends) {
    const { code: code2, map: map2 } = await readCodeMap(prepend, readMap);
    sources = sources.concat(await getSources({ file: prepend, code: code2, map: map2, ...childOptions }));
  }
  sources = sources.concat({ file, code, map });
  for (const append of children.appends) {
    const { code: code2, map: map2 } = await readCodeMap(append, readMap);
    sources = sources.concat(await getSources({ file: append, code: code2, map: map2, ...childOptions }));
  }
  return sources;
}
async function concat(code, options = {}) {
  const file = options.file;
  const map = options.inputSourceMap;
  const sourceMap = options.sourceMap || false;
  const rootDir = options.rootDir;
  const sources = await getSources({ file, code, map, rootDir, readMap: sourceMap });
  return await joinSources(sources, { sourceMap });
}

==> js-concat-8.0.0.tgz: package/lib/index.js <==
var __create = Object.create;
var __defProp = Object.defineProperty;
var __getOwnPropDesc = Object.getOwnPropertyDescriptor;
var __getOwnPropNames = Object.getOwnPropertyNames;
var __getProtoOf = Object.getPrototypeOf;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __export = (target, all) => {
  for (var name in all)
    __defProp(target, name, { get: all[name], enumerable: true });
};
var __copyProps = (to, from, except, desc) => {
  if (from && typeof from === "object" || typeof from === "function") {
    for (let key of __getOwnPropNames(from))
      if (!__hasOwnProp.call(to, key) && key !== except)
        __defProp(to, key, { get: () => from[key], enumerable: !(desc = __getOwnPropDesc(from, key)) || desc.enumerable });
  }
  return to;
};
var __toESM = (mod, isNodeMode, target) => (target = mod != null ? __create(__getProtoOf(mod)) : {}, __copyProps(
  // If the importer is in node compatibility mode or this is not an ESM
  // file that has been converted to a CommonJS file using a Babel-
  // compatible transform (i.e. "__esModule" has not been set), then set
  // "default" to the CommonJS "module.exports" for node compatibility.
  isNodeMode || !mod || !mod.__esModule ? __defProp(target, "default", { value: mod, enumerable: true }) : target,
  mod
));
var __toCommonJS = (mod) => __copyProps(__defProp({}, "__esModule", { value: true }), mod);

// src/index.js
var src_exports = {};
__export(src_exports, {
  default: () => concat
});
module.exports = __toCommonJS(src_exports);
var import_promises2 = require("node:fs/promises");

// src/resolver.js
var import_node_path = __toESM(require("node:path"));
var import_promises = __toESM(require("node:fs/promises"));
var REGX_APPEND = /\/\/(\s+|)@(prepros-|codekit-|)append/;
var REGX_PREPEND = /\/\/(\s+|)@(prepros-|codekit-|)prepend/;
var Resolver = class {
  constructor(options) {
    this.file = options.file;
    this.code = options.code;
    this.parents = options.parents;
    this.baseDir = import_node_path.default.dirname(this.file);
    this.rootDir = options.rootDir || this.baseDir;
  }
  async exists(file) {
    return await import_promises.default.access(file, import_promises.default.constants.F_OK).then(() => true).catch(() => false);
  }
  getMatches(regx) {
    let matches = [];
    for (const [index, code] of this.code.split("\n").entries()) {
      if (regx.test(code)) {
        matches = matches.concat(
          code.replace(regx, "").replace(/;|'|"/gi, "").split(",").filter((match) => !!match).map((match) => match.trim().replace(/^quiet\s+/, "").replace(/\s+quiet$/, "")).map((match) => ({ match: match.trim(), line: index + 1 }))
        );
      }
    }
    return matches;
  }
  async _resolveMatch(match) {
    const name = import_node_path.default.basename(match, ".js");
    const possibleNames = [`${name}.js`, `_${name}.js`];
    for (const name2 of possibleNames) {
      const filePath = import_node_path.default.resolve(this.baseDir, import_node_path.default.dirname(match), name2);
      if (await this.exists(filePath))
        return filePath;
    }
    throw new Error(`Unable to find the included file \`${match}\``);
  }
  // resolve full path/paths of a match
  async resolveMatch({ match, line }) {
    let files = [];
    try {
      files = files.concat(await this._resolveMatch(match));
      files.forEach((file) => {
        if (file === this.file)
          throw new Error(`\`${import_node_path.default.relative(this.rootDir, file)}\` can not be appended/prepended to itself`);
      });
      files.forEach((file) => {
        if (this.parents.includes(file))
          throw new Error(`\`${import_node_path.default.relative(this.rootDir, this.file)}\` can not append/prepend the parent file \`${import_node_path.default.relative(this.rootDir, file)}\``);
      });
    } catch (err) {
      err.line = line;
      err.column = 1;
      err.file = this.file;
      throw err;
    }
    return files;
  }
  async resolve(regx) {
    let result = [];
    const matches = this.getMatches(regx);
    for (const { match, line } of matches) {
      result = result.concat(await this.resolveMatch({ match, line }));
    }
    return result;
  }
  async resolveAll() {
    const [prepends, appends] = await Promise.all(
      [REGX_PREPEND, REGX_APPEND].map((regx) => this.resolve(regx))
    );
    return { prepends, appends };
  }
};

// src/join-sources.js
var import_source_map = require("source-map");
var import_node_path2 = __toESM(require("node:path"));
var REGX_APPEND2 = /\/\/(\s+|)@(prepros-|codekit-|)append/;
var REGX_PREPEND2 = /\/\/(\s+|)@(prepros-|codekit-|)prepend/;
var REGX_SOURCEMAP = /\/\/(\s+|)[@#](\s+|)sourceMappingURL=/;
function slash(path3) {
  return path3.replaceAll("\\", "/");
}
async function joinWithoutSourceMap(sources) {
  return sources.map((source) => {
    return source.code.split("\n").filter((line) => !REGX_APPEND2.test(line)).filter((line) => !REGX_PREPEND2.test(line)).filter((line) => !REGX_SOURCEMAP.test(line)).join("\n");
  }).join("\n");
}
async function joinWithSourceMap(sources, output) {
  const result = new import_source_map.SourceNode();
  for (const source of sources) {
    let inputMap = source.map ? await new import_source_map.SourceMapConsumer(source.map) : null;
    for (const [lineIndex, line] of source.code.split("\n").entries()) {
      if (REGX_APPEND2.test(line))
        continue;
      if (REGX_PREPEND2.test(line))
        continue;
      if (REGX_SOURCEMAP.test(line))
        continue;
      for (const [columnIndex, column] of line.split("").entries()) {
        let position = {
          line: lineIndex + 1,
          column: columnIndex + 1,
          source: slash(import_node_path2.default.relative(import_node_path2.default.dirname(output), source.file))
          // make source paths relative
        };
        if (inputMap) {
          const originalPosition = inputMap.originalPositionFor({ line: position.line, column: position.column });
          if (originalPosition && originalPosition.source) {
            let originalSource = import_node_path2.default.resolve(import_node_path2.default.dirname(source.file), originalPosition.source);
            originalSource = slash(import_node_path2.default.relative(import_node_path2.default.dirname(output), originalSource));
            position = { line: originalPosition.line, column: originalPosition.column, source: originalSource };
          }
        }
        result.add(new import_source_map.SourceNode(position.line, position.column, position.source, column));
      }
      result.add("\n");
    }
    if (inputMap)
      inputMap.destroy();
  }
  return result.toStringWithSourceMap();
}
async function joinSources(sources, { output, sourceMap }) {
  if (sourceMap)
    return await joinWithSourceMap(sources, output);
  return { code: await joinWithoutSourceMap(sources), map: null };
}

// src/index.js
async function readCodeMap(file, readMap) {
  const code = await (0, import_promises2.readFile)(file, "utf-8");
  if (!readMap)
    return { code };
  const map = await (0, import_promises2.readFile)(`${file}.map`, "utf-8").catch(() => {
  });
  return { code, map };
}
async function getSources({ file, code, map, readMap, rootDir, parents }) {
  if (!file)
    throw new Error("`file` is required");
  if (typeof code !== "string")
    throw new Error("`code` must be a string");
  if (!parents)
    parents = [];
  let sources = [];
  const children = await new Resolver({ file, code, rootDir, parents }).resolveAll();
  const childOptions = { readMap, rootDir, parents: parents.concat(file) };
  for (const prepend of children.prepends) {
    const { code: code2, map: map2 } = await readCodeMap(prepend, readMap);
    sources = sources.concat(await getSources({ file: prepend, code: code2, map: map2, ...childOptions }));
  }
  sources = sources.concat({ file, code, map });
  for (const append of children.appends) {
    const { code: code2, map: map2 } = await readCodeMap(append, readMap);
    sources = sources.concat(await getSources({ file: append, code: code2, map: map2, ...childOptions }));
  }
  return sources;
}
async function concat(code, options = {}) {
  const file = options.file;
  const map = options.inputSourceMap;
  const sourceMap = options.sourceMap || false;
  const rootDir = options.rootDir;
  const output = options.output;
  if (!output)
    throw new Error("`output` is required");
  const sources = await getSources({ file, code, map, rootDir, readMap: sourceMap });
  return await joinSources(sources, { output, sourceMap });
}
